from distutils.core import setup

setup(
    name = 'nester_sbb',
    version = '1.0.0',
    py_modules = ['nester_sbb'],
    author = 'xianggb',
    author_email = 'xiangguobo@163.com',
    url = 'http://www.163.com',
    description = 'A simple printer of nested lists',
    )
